==> galette-0.9.4.1.tar.bz2: galette-0.9.4.1/galette/lib/Galette/IO/File.php <==
<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * Files
 *
 * PHP version 5
 *
 * Copyright © 2013-2014 The Galette Team
 *
 * This file is part of Galette (http://galette.tuxfamily.org).
 *
 * Galette is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Galette is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Galette. If not, see <http://www.gnu.org/licenses/>.
 *
 * @category  IO
 * @package   Galette
 *
 * @author    Johan Cwiklinski <johan@x-tnd.be>
 * @copyright 2013-2014 The Galette Team
 * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
 * @link      http://galette.tuxfamily.org
 * @since     Available since 0.7.7dev - 2013-09-06
 */

namespace Galette\IO;

use Analog\Analog;
use Galette\IO\FileTrait;

/**
 * Files
 *
 * @category  IO
 * @name      Csv
 * @package   Galette
 * @author    Johan Cwiklinski <johan@x-tnd.be>
 * @copyright 2013-2014 The Galette Team
 * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
 * @link      http://galette.tuxfamily.org
 * @since     Available since 0.7.7dev - 2013-09-06
 */

class File implements FileInterface
{
    use FileTrait;

    /**
     * Default constructor
     *
     * @param string $dest       File destination directory
     * @param array  $extensions Array of permitted extensions
     * @param array  $mimes      Array of permitted mime types
     * @param int    $maxlenght  Maximum lenght for each file
     */
    public function __construct(
        $dest,
        $extensions = null,
        $mimes = null,
        $maxlenght = null
    ) {
        $this->init(
            $dest,
            $extensions,
            $mimes,
            $maxlenght
        );
    }
}

==> galette-1.1.0.tar.bz2: galette-1.1.0/galette/lib/Galette/IO/File.php <==
<?php

/**
 * Copyright © 2003-2024 The Galette Team
 *
 * This file is part of Galette (https://galette.eu).
 *
 * Galette is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Galette is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Galette. If not, see <http://www.gnu.org/licenses/>.
 */

declare(strict_types=1);

namespace Galette\IO;

use Analog\Analog;
use Galette\IO\FileTrait;

/**
 * Files
 *
 * @author Johan Cwiklinski <johan@x-tnd.be>
 */

class File implements FileInterface
{
    use FileTrait;

    /**
     * Default constructor
     *
     * @param string                $dest       File destination directory
     * @param ?array<int,string>    $extensions Array of permitted extensions
     * @param ?array<string,string> $mimes      Array of permitted mime types
     * @param ?int                  $maxlenght  Maximum length for each file
     */
    public function __construct(
        string $dest,
        array $extensions = null,
        array $mimes = null,
        int $maxlenght = null
    ) {
        $this->init(
            $dest,
            $extensions,
            $mimes,
            $maxlenght
        );
    }
}
